@@ -57,12 +57,6 @@ def mark_media_watched(args, files):
 def mark_media_deleted(args, paths):
     paths = utils.conform(paths)
 
-    mount_point = args.prefix or args.shallow_organize
-    if platform.system() == "Linux" and any([mount_point in p for p in paths]):
-        p = Path(mount_point)
-        if p.exists() and not p.is_mount():
-            raise Exception(f"mount_point {mount_point} not mounted yet")
-
     modified_row_count = 0
     if len(paths) > 0:
         df_chunked = utils.chunks(paths, SQLITE_PARAM_LIMIT)
@@ -165,17 +159,17 @@ def get_ordinal_media(args, path):
             return path
 
         candidate = new_candidate
-        query = f"""SELECT path FROM media
+        query = f"""SELECT path FROM {args.table}
             WHERE 1=1
-                and path like ?
+                and path like :candidate
                 {'and is_deleted=0' if args.action in [SC.listen, SC.watch] else ''}
                 {'' if (args.play_in_order > 2) else (args.sql_filter or '')}
             ORDER BY path
             LIMIT 1000
             """
-        bindings = ["%" + candidate + "%"]
+        bindings = {"candidate": "%" + candidate + "%"}
         if not args.play_in_order > 2:
-            bindings.extend(args.sql_filter_bindings)
+            bindings = {**bindings, **args.sql_filter_bindings}
 
         similar_videos = [d["path"] for d in args.db.query(query, bindings)]
         log.debug(similar_videos)
@@ -195,7 +189,7 @@ def get_ordinal_media(args, path):
 def generic_player(args):
     if platform.system() == "Linux":
         player = ["xdg-open"]
-    elif any([p in platform.system() for p in ["Windows", '_NT-', 'MSYS']]):
+    elif any([p in platform.system() for p in ["Windows", "_NT-", "MSYS"]]):
         if shutil.which("cygstart"):
             player = ["cygstart"]
         else:
@@ -338,6 +332,14 @@ def local_player(args, m, media_file):
             if end != m["duration"]:
                 player.extend([f"--end={int(end)}"])
 
+        if args.action == SC.watch:
+            if m["subtitle_count"] > 0:
+                player.extend(args.player_args_when_sub)
+            elif m["time_started"] is not None or Path(media_file).stat().st_size > 500 * 1000000:  # 500 MB
+                pass
+            else:
+                player.extend(args.player_args_when_no_sub)
+
     elif system() == "Linux":
         mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
         default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
@@ -346,15 +348,6 @@ def local_player(args, m, media_file):
             args.player_need_sleep = False
             player = [player_path]
 
-    if args.action == SC.watch:
-        if m["subtitle_count"] > 0:
-            player.extend(args.player_args_when_sub)
-        elif Path(media_file).stat().st_size > 500 * 1000000:  # 500 MB
-            # player.extend(args.player_args_when_no_sub_big_file) # TODO: if people complain fix this
-            pass
-        else:
-            player.extend(args.player_args_when_no_sub)
-
     if system() == "Windows" or args.action in [SC.watch, SC.tubewatch]:
         r = cmd(*player, media_file, strict=False)
     else:  # args.action in [SC.listen, SC.tubelisten]
@@ -448,7 +441,8 @@ def printer(args, query, bindings):
             summary = db_resp.sum(numeric_only=True)
             duration = summary.get("duration") or 0
             duration = human_time(duration)
-            print("Total duration:", duration)
+            if not "a" in args.print:
+                print("Total duration:", duration)
 
 
 def override_sort(string):
